@@ -22,19 +22,18 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
-                            '-Werror=odr -Werror=lto-type-mismatch '
-                            '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                            '-flto -fuse-linker-plugin -ffat-lto-objects -g '
-                            '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                            '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
+                            '-ffat-lto-objects -g -std=c99 -Wextra '
+                            '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -61,7 +60,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--without-ensurepip' '--without-lto' '--with-system-expat' "
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
+                "'--with-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' 'CFLAGS=' 'LDFLAGS=' "
@@ -634,7 +633,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG',
+ 'OPT': '',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -668,8 +667,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe -march=x86-64 -mtune=generic -Werror=odr '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
+                             '-march=x86-64-v3 -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -ffat-lto-objects '
                              '-flto -fuse-linker-plugin -ffat-lto-objects -g '
@@ -681,8 +680,8 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
                      '-ffat-lto-objects -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
@@ -691,14 +690,14 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
-                   '-march=x86-64 -mtune=generic -Werror=odr '
-                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
-                   '-ffat-lto-objects -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
+                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
@@ -714,8 +713,8 @@ build_time_vars = {'ABIFLAGS': '',
                       '-ffat-lto-objects -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
-                        '-march=x86-64 -mtune=generic -Werror=odr '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
+                        '-march=x86-64-v3 -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
                         '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
                         '-ffat-lto-objects -g -std=c99 -Wextra '
